@@ -297,13 +297,8 @@ InputSource* PSVIWriterHandlers::resolveEntity(const XMLCh* const, const XMLCh*
 void PSVIWriterHandlers::error(const SAXParseException& e) {
 	XMLCh* temp1 = new XMLCh[10];
 	XMLCh* temp2 = new XMLCh[10];
-#if XERCES_SIZEOF_INT != 8 && XERCES_SIZEOF_LONG != 8 && XERCES_SIZEOF_INT64 != 4
-	XMLString::binToText(e.getLineNumber(), temp1, 9, 10);
-	XMLString::binToText(e.getColumnNumber(), temp2, 9, 10);
-#else
         XMLString::binToText((unsigned long)e.getLineNumber(), temp1, 9, 10);
 	XMLString::binToText((unsigned long)e.getColumnNumber(), temp2, 9, 10);
-#endif
 	*fErrorFormatter << fgError << fgAtFile << chSpace << e.getSystemId()
 		<< chComma << fgLine << chSpace << temp1
 		<< chComma << fgChar << chSpace << temp2
@@ -315,13 +310,8 @@ void PSVIWriterHandlers::error(const SAXParseException& e) {
 void PSVIWriterHandlers::fatalError(const SAXParseException& e) {
 	XMLCh* temp1 = new XMLCh[10];
 	XMLCh* temp2 = new XMLCh[10];
-#if XERCES_SIZEOF_INT != 8 && XERCES_SIZEOF_LONG != 8 && XERCES_SIZEOF_INT64 != 4
-	XMLString::binToText(e.getLineNumber(), temp1, 9, 10);
-	XMLString::binToText(e.getColumnNumber(), temp2, 9, 10);
-#else
         XMLString::binToText((unsigned long)e.getLineNumber(), temp1, 9, 10);
 	XMLString::binToText((unsigned long)e.getColumnNumber(), temp2, 9, 10);
-#endif
 	*fErrorFormatter << fgFatalError << fgAtFile << chSpace << e.getSystemId()
 		<< chComma << fgLine << chSpace << temp1
 		<< chComma << fgChar << chSpace << temp2
@@ -334,13 +324,8 @@ void PSVIWriterHandlers::fatalError(const SAXParseException& e) {
 void PSVIWriterHandlers::warning(const SAXParseException& e) {
 	XMLCh* temp1 = new XMLCh[10];
 	XMLCh* temp2 = new XMLCh[10];
-#if XERCES_SIZEOF_INT != 8 && XERCES_SIZEOF_LONG != 8 && XERCES_SIZEOF_INT64 != 4
-	XMLString::binToText(e.getLineNumber(), temp1, 9, 10);
-	XMLString::binToText(e.getColumnNumber(), temp2, 9, 10);
-#else
         XMLString::binToText((unsigned long)e.getLineNumber(), temp1, 9, 10);
 	XMLString::binToText((unsigned long)e.getColumnNumber(), temp2, 9, 10);
-#endif
 	*fErrorFormatter << fgWarning << fgAtFile << chSpace << e.getSystemId()
 		<< chComma << fgLine << chSpace << temp1
 		<< chComma << fgChar << chSpace << temp2
@@ -1636,7 +1621,7 @@ XMLCh* PSVIWriterHandlers::createID(XSObject* obj) {
 
 const XMLCh* PSVIWriterHandlers::getIdName(XSObject* obj) {
 	XMLCh* objLoc = new XMLCh[9];
-	XMLString::binToText((unsigned long)(XMLSize_t)obj, objLoc, 8, 16);
+	XMLString::sizeToText((XMLSize_t)obj, objLoc, 8, 16);
 	XMLCh* idName = fIdMap->get(objLoc);
 	if (!idName) {
 		idName = createID(obj);
