@@ -16,7 +16,7 @@
  */
 
 /*
- * $Id: DOMLSSerializerImpl.cpp 695864 2008-09-16 13:15:25Z borisk $
+ * $Id: DOMLSSerializerImpl.cpp 768978 2009-04-27 13:45:52Z amassari $
  */
 
 #include "DOMLSSerializerImpl.hpp"
@@ -312,23 +312,23 @@ DOMLSSerializerImpl::DOMLSSerializerImpl(MemoryManager* const manager)
     fSupportedParameters->add(XMLUni::fgDOMWRTXercesPrettyPrint);
 }
 
-bool DOMLSSerializerImpl::canSetParameter(const XMLCh* const featName
-                                        , const void*        /*value*/) const
+bool DOMLSSerializerImpl::canSetParameter(const XMLCh* featName
+                                        , const void*  /*value*/) const
 {
     if(XMLString::compareIStringASCII(featName, XMLUni::fgDOMErrorHandler)==0)
         return true;
     return false;
 }
 
-bool DOMLSSerializerImpl::canSetParameter(const XMLCh* const featName
-                                        , bool               state) const
+bool DOMLSSerializerImpl::canSetParameter(const XMLCh* featName
+                                        , bool         state) const
 {
     int featureId = INVALID_FEATURE_ID;
     return checkFeature(featName, false, featureId) ? canSetFeature(featureId, state) : false;
 }
 
-void DOMLSSerializerImpl::setParameter(const XMLCh* const featName
-                                     , const void*        value)
+void DOMLSSerializerImpl::setParameter(const XMLCh* featName
+                                     , const void*  value)
 {
     if(XMLString::compareIStringASCII(featName, XMLUni::fgDOMErrorHandler)==0)
         fErrorHandler = (DOMErrorHandler*)value;
@@ -336,8 +336,8 @@ void DOMLSSerializerImpl::setParameter(const XMLCh* const featName
         throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0, fMemoryManager);
 }
 
-void DOMLSSerializerImpl::setParameter(const XMLCh* const featName
-                                     , bool               state)
+void DOMLSSerializerImpl::setParameter(const XMLCh* featName
+                                     , bool         state)
 {
     int featureId = INVALID_FEATURE_ID;
     checkFeature(featName, true, featureId);
@@ -363,7 +363,7 @@ void DOMLSSerializerImpl::setParameter(const XMLCh* const featName
         setFeature(CANONICAL_FORM_ID, false);
 }
 
-const void* DOMLSSerializerImpl::getParameter(const XMLCh* const featName) const
+const void* DOMLSSerializerImpl::getParameter(const XMLCh* featName) const
 {
     if(XMLString::compareIStringASCII(featName, XMLUni::fgDOMErrorHandler)==0)
     {
@@ -1683,7 +1683,8 @@ void DOMLSSerializerImpl::processBOM()
     else if ((XMLString::compareIStringASCII(fEncodingUsed, XMLUni::fgUCS4EncodingString)  == 0) ||
              (XMLString::compareIStringASCII(fEncodingUsed, XMLUni::fgUCS4EncodingString2) == 0) ||
              (XMLString::compareIStringASCII(fEncodingUsed, XMLUni::fgUCS4EncodingString3) == 0) ||
-             (XMLString::compareIStringASCII(fEncodingUsed, XMLUni::fgUCS4EncodingString4) == 0)  )
+             (XMLString::compareIStringASCII(fEncodingUsed, XMLUni::fgUCS4EncodingString4) == 0) ||
+             (XMLString::compareIStringASCII(fEncodingUsed, XMLUni::fgUCS4EncodingString5) == 0)  )
     {
 		if (XMLPlatformUtils::fgXMLChBigEndian)
 	        fFormatter->writeBOM(BOM_ucs4be, 4);
