@@ -16,7 +16,7 @@
  */
 
 /*
- * $Id: LocalFileFormatTarget.hpp 882540 2009-11-20 13:02:07Z borisk $
+ * $Id: LocalFileFormatTarget.hpp 932887 2010-04-11 13:04:59Z borisk $
  */
 
 #if !defined(XERCESC_INCLUDE_GUARD_LOCALFILEFORMATTARGET_HPP)
@@ -65,7 +65,7 @@ private:
     // -----------------------------------------------------------------------
     //  Private helpers
     // -----------------------------------------------------------------------
-    void insureCapacity(const XMLSize_t extraNeeded);
+    void ensureCapacity(const XMLSize_t extraNeeded);
 
     // -----------------------------------------------------------------------
     //  Private data members
