@@ -5,9 +5,9 @@
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -16,7 +16,7 @@
  */
 
 /*
- * $Id: XMLURL.cpp 670359 2008-06-22 13:43:45Z borisk $
+ * $Id: XMLURL.cpp 901107 2010-01-20 08:45:02Z borisk $
  */
 
 
@@ -116,9 +116,9 @@ static const XMLCh gListSix[]    = { chPound, chNull };
 // ---------------------------------------------------------------------------
 static bool isHexDigit(const XMLCh toCheck)
 {
-    if ((toCheck >= chDigit_0) && (toCheck <= chDigit_9)
-    ||  (toCheck >= chLatin_A) && (toCheck <= chLatin_Z)
-    ||  (toCheck >= chLatin_a) && (toCheck <= chLatin_z))
+    if (((toCheck >= chDigit_0) && (toCheck <= chDigit_9))
+    ||  ((toCheck >= chLatin_A) && (toCheck <= chLatin_Z))
+    ||  ((toCheck >= chLatin_a) && (toCheck <= chLatin_z)))
     {
         return true;
     }
@@ -193,7 +193,7 @@ XMLURL::XMLURL(const XMLCh* const    baseURL
     CleanupType cleanup(this, &XMLURL::cleanUp);
 
 	try
-	{	
+	{
         setURL(baseURL, relativeURL);
 	}
     catch(const OutOfMemoryException&)
@@ -535,11 +535,11 @@ bool XMLURL::setURL(const XMLCh* const    baseURL
 	    //  parse the base URL string and conglomerate them.
 	    //
 	    if (isRelative() && baseURL && *baseURL)
-	    {		   
+	    {
 	        XMLURL basePart(fMemoryManager);
             if (parse(baseURL, basePart)  && conglomerateWithBase(basePart, false))
-            {    
-		        return true;			                    
+            {
+		        return true;
 		    }
 	    }
         else
@@ -635,7 +635,10 @@ BinInputStream* XMLURL::makeNewStream() const
                 realPath[i] = chNull;
                 end = i;
 
-                percentIndex = XMLString::indexOf(realPath, chPercent, percentIndex, fMemoryManager);
+                if (((XMLSize_t)(percentIndex + 1)) < end)
+                  percentIndex = XMLString::indexOf(realPath, chPercent, percentIndex + 1, fMemoryManager);
+                else
+                  percentIndex = -1;
             }
 
 
@@ -1224,7 +1227,7 @@ bool XMLURL::parse(const XMLCh* const urlText, XMLURL& xmlURL)
 
     //
     //  The first thing we will do is to check for a file name, so that
-    //  we don't waste time thinking its a URL. If its in the form x:\ or x:/ 
+    //  we don't waste time thinking its a URL. If its in the form x:\ or x:/
     //  and x is an ASCII letter, then assume that's the deal.
     //
     if (((*urlText >= chLatin_A) && (*urlText <= chLatin_Z))
@@ -1485,4 +1488,3 @@ bool XMLURL::parse(const XMLCh* const urlText, XMLURL& xmlURL)
 }
 
 XERCES_CPP_NAMESPACE_END
-
