@@ -16,7 +16,7 @@
  */
 
 /*
- * $Id: DTDValidator.cpp 676911 2008-07-15 13:27:32Z amassari $
+ * $Id: DTDValidator.cpp 729944 2008-12-29 17:03:32Z amassari $
  */
 
 
@@ -478,7 +478,7 @@ void DTDValidator::preContentValidation(bool
         bool seenNOTATION = false;
         bool elemEmpty = (curElem.getModelType() == DTDElementDecl::Empty);
 
-        for(unsigned int i=0; i<attDefList.getAttDefCount(); i++)
+        for(XMLSize_t i=0; i<attDefList.getAttDefCount(); i++)
         {
             const XMLAttDef& curAttDef = attDefList.getAttDef(i);
 
