@@ -16,7 +16,7 @@
  */
 
 /*
- * $Id: MemoryMonitor.cpp 698591 2008-09-24 14:35:36Z borisk $
+ * $Id: MemoryMonitor.cpp 833057 2009-11-05 15:25:10Z borisk $
  */
 
 
@@ -287,6 +287,10 @@ int main (int argC,  char *argV[])
     sax2parser->setFeature(XMLUni::fgXercesSchema, doSchema);
     saxParser->setDoSchema(doSchema);
 
+    domBuilder->getDomConfig()->setParameter(XMLUni::fgXercesHandleMultipleImports, true);
+    sax2parser->setFeature(XMLUni::fgXercesHandleMultipleImports, true);
+    saxParser->setHandleMultipleImports (true);
+
     domBuilder->getDomConfig()->setParameter(XMLUni::fgXercesSchemaFullChecking, schemaFullChecking);
     sax2parser->setFeature(XMLUni::fgXercesSchemaFullChecking, schemaFullChecking);
     saxParser->setValidationSchemaFullChecking(schemaFullChecking);
@@ -436,4 +440,3 @@ int main (int argC,  char *argV[])
     delete staticMemMonitor;
     return 0;
 }
-
